@@ -4,10 +4,13 @@
 int main(int argc, char *argv[])
 {
     QApplication a(argc, argv);
-
+    a.setApplicationName("FMRadio");
     MainWindow w;
+#if defined(Q_WS_S60)
+    w.showMaximized();
+#else
     w.show();
-
+#endif
 
     return a.exec();
 }
