@@ -47,7 +47,7 @@ MainWindow::MainWindow(QWidget *parent) :
 
     system("amixer -qc0 cset iface=MIXER,name='Jack Bias Switch' on");
 
-
+    ui->actionAuto_Scan->setEnabled(false); //AutoScan feature unstable.
 
 
 }
@@ -356,7 +356,7 @@ void MainWindow::setWidgetsEnabled(bool enable)
  ui->stationsListWidget->setEnabled(enable);
 
  ui->actionManual->setEnabled(enable);
- ui->actionAuto_Scan->setEnabled(enable);
+ //ui->actionAuto_Scan->setEnabled(enable);
  ui->actionHeadphones->setEnabled(enable);
  ui->actionSpeakers->setEnabled(enable);
 
@@ -573,7 +573,7 @@ void MainWindow::on_actionManual_triggered()
 void MainWindow::on_actionAbout_triggered()
 {
     QMessageBox::about(this, tr("About QRadio"),
-                    tr("<h2>QRadio 0.4.9</h2>"
+                    tr("<h2>QRadio 0.4.10</h2>"
                        "<p>"
                        "<p>Written by Giovanni Grammatico (ggiovanni88@yahoo.it)"));
 }
@@ -622,7 +622,7 @@ void MainWindow::settingsChanged()
     changeFont();
 }
 
-void MainWindow::on_actionAuto_Scan_triggered()
+void MainWindow::on_actionAuto_Scan_triggered()  //Menu action disabled.
 {
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
     int tempFreq = radio->frequency();
@@ -862,3 +862,11 @@ void MainWindow::restartRadio()
 }
 
 
+
+void MainWindow::on_actionHelp_triggered()
+{
+
+    GuideWindow *guideWindow = new GuideWindow(this);
+    guideWindow->show();
+
+}
